==> huaweicloudsdkconfig-3.1.122-py2.py3-none-any.whl: huaweicloudsdkconfig/v1/model/update_stored_query_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateStoredQueryResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'description': 'str',
        'expression': 'str',
        'created': 'str',
        'updated': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'description': 'description',
        'expression': 'expression',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, id=None, name=None, type=None, description=None, expression=None, created=None, updated=None):
        """UpdateStoredQueryResponse

        The model defined in huaweicloud sdk

        :param id: ResourceQL ID
        :type id: str
        :param name: ResourceQL 名字
        :type name: str
        :param type: 自定义查询类型，枚举值为“account”和“aggregator”。若取值为“account”，表示单帐号的自定义查询语句；若取值为“aggregator”，表示聚合器的自定义查询语句。默认值为“account”。
        :type type: str
        :param description: ResourceQL 描述
        :type description: str
        :param expression: ResourceQL 表达式
        :type expression: str
        :param created: ResourceQL 创建时间
        :type created: str
        :param updated: ResourceQL 更新时间
        :type updated: str
        """
        
        super(UpdateStoredQueryResponse, self).__init__()

        self._id = None
        self._name = None
        self._type = None
        self._description = None
        self._expression = None
        self._created = None
        self._updated = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if expression is not None:
            self.expression = expression
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def id(self):
        """Gets the id of this UpdateStoredQueryResponse.

        ResourceQL ID

        :return: The id of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdateStoredQueryResponse.

        ResourceQL ID

        :param id: The id of this UpdateStoredQueryResponse.
        :type id: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this UpdateStoredQueryResponse.

        ResourceQL 名字

        :return: The name of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateStoredQueryResponse.

        ResourceQL 名字

        :param name: The name of this UpdateStoredQueryResponse.
        :type name: str
        """
        self._name = name

    @property
    def type(self):
        """Gets the type of this UpdateStoredQueryResponse.

        自定义查询类型，枚举值为“account”和“aggregator”。若取值为“account”，表示单帐号的自定义查询语句；若取值为“aggregator”，表示聚合器的自定义查询语句。默认值为“account”。

        :return: The type of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateStoredQueryResponse.

        自定义查询类型，枚举值为“account”和“aggregator”。若取值为“account”，表示单帐号的自定义查询语句；若取值为“aggregator”，表示聚合器的自定义查询语句。默认值为“account”。

        :param type: The type of this UpdateStoredQueryResponse.
        :type type: str
        """
        self._type = type

    @property
    def description(self):
        """Gets the description of this UpdateStoredQueryResponse.

        ResourceQL 描述

        :return: The description of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateStoredQueryResponse.

        ResourceQL 描述

        :param description: The description of this UpdateStoredQueryResponse.
        :type description: str
        """
        self._description = description

    @property
    def expression(self):
        """Gets the expression of this UpdateStoredQueryResponse.

        ResourceQL 表达式

        :return: The expression of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """Sets the expression of this UpdateStoredQueryResponse.

        ResourceQL 表达式

        :param expression: The expression of this UpdateStoredQueryResponse.
        :type expression: str
        """
        self._expression = expression

    @property
    def created(self):
        """Gets the created of this UpdateStoredQueryResponse.

        ResourceQL 创建时间

        :return: The created of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this UpdateStoredQueryResponse.

        ResourceQL 创建时间

        :param created: The created of this UpdateStoredQueryResponse.
        :type created: str
        """
        self._created = created

    @property
    def updated(self):
        """Gets the updated of this UpdateStoredQueryResponse.

        ResourceQL 更新时间

        :return: The updated of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this UpdateStoredQueryResponse.

        ResourceQL 更新时间

        :param updated: The updated of this UpdateStoredQueryResponse.
        :type updated: str
        """
        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateStoredQueryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkconfig-3.1.146-py2.py3-none-any.whl: huaweicloudsdkconfig/v1/model/update_stored_query_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateStoredQueryResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'description': 'str',
        'expression': 'str',
        'created': 'str',
        'updated': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'description': 'description',
        'expression': 'expression',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, id=None, name=None, type=None, description=None, expression=None, created=None, updated=None):
        r"""UpdateStoredQueryResponse

        The model defined in huaweicloud sdk

        :param id: ResourceQL ID
        :type id: str
        :param name: ResourceQL 名字
        :type name: str
        :param type: 自定义查询类型，枚举值为“account”和“aggregator”。若取值为“account”，表示单帐号的自定义查询语句；若取值为“aggregator”，表示聚合器的自定义查询语句。默认值为“account”。
        :type type: str
        :param description: ResourceQL 描述
        :type description: str
        :param expression: ResourceQL 表达式
        :type expression: str
        :param created: ResourceQL 创建时间
        :type created: str
        :param updated: ResourceQL 更新时间
        :type updated: str
        """
        
        super(UpdateStoredQueryResponse, self).__init__()

        self._id = None
        self._name = None
        self._type = None
        self._description = None
        self._expression = None
        self._created = None
        self._updated = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if expression is not None:
            self.expression = expression
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def id(self):
        r"""Gets the id of this UpdateStoredQueryResponse.

        ResourceQL ID

        :return: The id of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this UpdateStoredQueryResponse.

        ResourceQL ID

        :param id: The id of this UpdateStoredQueryResponse.
        :type id: str
        """
        self._id = id

    @property
    def name(self):
        r"""Gets the name of this UpdateStoredQueryResponse.

        ResourceQL 名字

        :return: The name of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this UpdateStoredQueryResponse.

        ResourceQL 名字

        :param name: The name of this UpdateStoredQueryResponse.
        :type name: str
        """
        self._name = name

    @property
    def type(self):
        r"""Gets the type of this UpdateStoredQueryResponse.

        自定义查询类型，枚举值为“account”和“aggregator”。若取值为“account”，表示单帐号的自定义查询语句；若取值为“aggregator”，表示聚合器的自定义查询语句。默认值为“account”。

        :return: The type of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this UpdateStoredQueryResponse.

        自定义查询类型，枚举值为“account”和“aggregator”。若取值为“account”，表示单帐号的自定义查询语句；若取值为“aggregator”，表示聚合器的自定义查询语句。默认值为“account”。

        :param type: The type of this UpdateStoredQueryResponse.
        :type type: str
        """
        self._type = type

    @property
    def description(self):
        r"""Gets the description of this UpdateStoredQueryResponse.

        ResourceQL 描述

        :return: The description of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        r"""Sets the description of this UpdateStoredQueryResponse.

        ResourceQL 描述

        :param description: The description of this UpdateStoredQueryResponse.
        :type description: str
        """
        self._description = description

    @property
    def expression(self):
        r"""Gets the expression of this UpdateStoredQueryResponse.

        ResourceQL 表达式

        :return: The expression of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        r"""Sets the expression of this UpdateStoredQueryResponse.

        ResourceQL 表达式

        :param expression: The expression of this UpdateStoredQueryResponse.
        :type expression: str
        """
        self._expression = expression

    @property
    def created(self):
        r"""Gets the created of this UpdateStoredQueryResponse.

        ResourceQL 创建时间

        :return: The created of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        r"""Sets the created of this UpdateStoredQueryResponse.

        ResourceQL 创建时间

        :param created: The created of this UpdateStoredQueryResponse.
        :type created: str
        """
        self._created = created

    @property
    def updated(self):
        r"""Gets the updated of this UpdateStoredQueryResponse.

        ResourceQL 更新时间

        :return: The updated of this UpdateStoredQueryResponse.
        :rtype: str
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        r"""Sets the updated of this UpdateStoredQueryResponse.

        ResourceQL 更新时间

        :param updated: The updated of this UpdateStoredQueryResponse.
        :type updated: str
        """
        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateStoredQueryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
